Nxpy Abstract
=============

You can install the library with pip::

    pip install nxpy-abstract

*Nxpy Abstract* implements the ``@abstractstatic`` decorator, which is equivalent to the
``@abstractstaticmethod`` decorator included in the ``abc`` standard package from Python 3.2.

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/abstract.html>`_.
